isReply property
bool
get
isReply
Checks if this message is a reply to another message
Implementation
bool get isReply => replyToMessageId != null;
Checks if this message is a reply to another message
bool get isReply => replyToMessageId != null;